==> nextcloud-20.0.12.tgz: nextcloud/apps/user_status/l10n/pt_BR.js <==
OC.L10N.register(
    "user_status",
    {
    "Recent statuses" : "Status recentes",
    "In a meeting" : "Em reunião",
    "Commuting" : "Em trânsito",
    "Out sick" : "Doente",
    "Vacationing" : "Férias",
    "Working remotely" : "Em trabalho remoto",
    "User status" : "Status do usuário",
    "Clear status message after" : "Limpar status do usuário após",
    "What's your status?" : "Qual é o seu status?",
    "Set status" : "Definir status",
    "Online status" : "Status online",
    "Status message" : "Mensagem de status",
    "Clear status message" : "Limpar mensagem de status",
    "Set status message" : "Definir mensagem de status",
    "There was an error saving the status" : "Ocorreu um erro ao salvar o status",
    "There was an error clearing the status" : "Ocorreu um erro ao limpar o status",
    "No recent status changes" : "Sem alterações de status recentes",
    "Away" : "Fora",
    "Do not disturb" : "Não perturbe",
    "{status}, {timestamp}" : "{status}, {timestamp}",
    "Don't clear" : "Não limpar",
    "Today" : "Hoje",
    "This week" : "Esta semana",
    "Online" : "Online",
    "Invisible" : "Invisível",
    "Offline" : "Offline",
    "There was an error saving the new status" : "Ocorreu um erro ao salvar o novo status",
    "30 minutes" : "30 minutos",
    "1 hour" : "1 hora",
    "4 hours" : "4 horas",
    "Mute all notifications" : "Silenciar todas as notificações",
    "Appear offline" : "Aparecer offline",
    "Clear status after" : "Limpar status após"
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-21.0.8.tgz: nextcloud/apps/user_status/l10n/pt_BR.js <==
OC.L10N.register(
    "user_status",
    {
    "Recent statuses" : "Status recentes",
    "In a meeting" : "Em reunião",
    "Commuting" : "Em trânsito",
    "Out sick" : "Doente",
    "Vacationing" : "Férias",
    "Working remotely" : "Em trabalho remoto",
    "In a call" : "Numa chamada",
    "User status" : "Status do usuário",
    "View profile" : "Visualizar perfil",
    "Clear status message after" : "Limpar status do usuário após",
    "What is your status?" : "Qual é o seu status?",
    "Set status" : "Definir status",
    "Online status" : "Status online",
    "Status message" : "Mensagem de status",
    "Clear status message" : "Limpar mensagem de status",
    "Set status message" : "Definir mensagem de status",
    "There was an error saving the status" : "Ocorreu um erro ao salvar o status",
    "There was an error clearing the status" : "Ocorreu um erro ao limpar o status",
    "No recent status changes" : "Sem alterações de status recentes",
    "Away" : "Fora",
    "Do not disturb" : "Não perturbe",
    "{status}, {timestamp}" : "{status}, {timestamp}",
    "Don't clear" : "Não limpar",
    "Today" : "Hoje",
    "This week" : "Esta semana",
    "Online" : "Online",
    "Invisible" : "Invisível",
    "Offline" : "Offline",
    "There was an error saving the new status" : "Ocorreu um erro ao salvar o novo status",
    "30 minutes" : "30 minutos",
    "1 hour" : "1 hora",
    "4 hours" : "4 horas",
    "Mute all notifications" : "Silenciar todas as notificações",
    "Appear offline" : "Aparecer offline",
    "Clear status after" : "Limpar status após",
    "What's your status?" : "Qual é o seu status?"
},
"nplurals=2; plural=(n > 1);");
